NAME
Sisimai::Reason::SyntaxError - Bounce reason is syntaxerror or not.
SYNOPSIS
use Sisimai::Reason::SyntaxError;
print Sisimai::Reason::SyntaxError->text; # syntaxerror
DESCRIPTION
Sisimai::Reason::SyntaxError checks the bounce reason is syntaxerror or not. This class is called only Sisimai::Reason class.
This is the error that a destination mail server could not recognize SMTP command which is sent from a sender's MTA. Sisimai will set syntaxerror to the reason if the value of replycode begins with "50" such as 502, or 503.
Action: failed
Status: 5.5.0
Diagnostic-Code: SMTP; 503 Improper sequence of commands
CLASS METHODS
text()
text() returns string: syntaxerror.
print Sisimai::Reason::SyntaxError->text; # syntaxerror
match(string)
match() always return undef
true(Sisimai::Data)
true() returns 1 if the bounce reason is syntaxerror. The argument must be Sisimai::Data object and this method is called only from Sisimai::Reason class.
AUTHOR
azumakuniyuki
COPYRIGHT
Copyright (C) 2015-2016,2018 azumakuniyuki, All rights reserved.
LICENSE
This software is distributed under The BSD 2-Clause License.